==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1StorageOSVolumeSourceFluent.java <==
package io.kubernetes.client.models;

import java.lang.Deprecated;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.Boolean;

public interface V1StorageOSVolumeSourceFluent<A extends V1StorageOSVolumeSourceFluent<A>> extends Fluent<A>{


    public String getFsType();
    public A withFsType(String fsType);
    public Boolean hasFsType();
    public Boolean isReadOnly();
    public A withReadOnly(Boolean readOnly);
    public Boolean hasReadOnly();
    public A withNewReadOnly(boolean arg1);
    public A withNewReadOnly(String arg1);
    
/**
 * This method has been deprecated, please use method buildSecretRef instead.
 * @return The buildable object.
 */
@Deprecated public V1LocalObjectReference getSecretRef();
    public V1LocalObjectReference buildSecretRef();
    public A withSecretRef(V1LocalObjectReference secretRef);
    public Boolean hasSecretRef();
    public V1StorageOSVolumeSourceFluent.SecretRefNested<A> withNewSecretRef();
    public V1StorageOSVolumeSourceFluent.SecretRefNested<A> withNewSecretRefLike(V1LocalObjectReference item);
    public V1StorageOSVolumeSourceFluent.SecretRefNested<A> editSecretRef();
    public V1StorageOSVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRef();
    public V1StorageOSVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRefLike(V1LocalObjectReference item);
    public String getVolumeName();
    public A withVolumeName(String volumeName);
    public Boolean hasVolumeName();
    public String getVolumeNamespace();
    public A withVolumeNamespace(String volumeNamespace);
    public Boolean hasVolumeNamespace();

    public interface SecretRefNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1LocalObjectReferenceFluent<V1StorageOSVolumeSourceFluent.SecretRefNested<N>>{

        
    public N and();    public N endSecretRef();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1StorageOSVolumeSourceFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface V1StorageOSVolumeSourceFluent<A extends V1StorageOSVolumeSourceFluent<A>> extends Fluent<A>{


    public String getFsType();
    public A withFsType(String fsType);
    public Boolean hasFsType();
    public A withNewFsType(String arg1);
    public A withNewFsType(StringBuilder arg1);
    public A withNewFsType(StringBuffer arg1);
    public Boolean isReadOnly();
    public A withReadOnly(Boolean readOnly);
    public Boolean hasReadOnly();
    public A withNewReadOnly(String arg1);
    public A withNewReadOnly(boolean arg1);
    
/**
 * This method has been deprecated, please use method buildSecretRef instead.
 * @return The buildable object.
 */
@Deprecated public V1LocalObjectReference getSecretRef();
    public V1LocalObjectReference buildSecretRef();
    public A withSecretRef(V1LocalObjectReference secretRef);
    public Boolean hasSecretRef();
    public V1StorageOSVolumeSourceFluent.SecretRefNested<A> withNewSecretRef();
    public V1StorageOSVolumeSourceFluent.SecretRefNested<A> withNewSecretRefLike(V1LocalObjectReference item);
    public V1StorageOSVolumeSourceFluent.SecretRefNested<A> editSecretRef();
    public V1StorageOSVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRef();
    public V1StorageOSVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRefLike(V1LocalObjectReference item);
    public String getVolumeName();
    public A withVolumeName(String volumeName);
    public Boolean hasVolumeName();
    public A withNewVolumeName(String arg1);
    public A withNewVolumeName(StringBuilder arg1);
    public A withNewVolumeName(StringBuffer arg1);
    public String getVolumeNamespace();
    public A withVolumeNamespace(String volumeNamespace);
    public Boolean hasVolumeNamespace();
    public A withNewVolumeNamespace(String arg1);
    public A withNewVolumeNamespace(StringBuilder arg1);
    public A withNewVolumeNamespace(StringBuffer arg1);

    public interface SecretRefNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1LocalObjectReferenceFluent<V1StorageOSVolumeSourceFluent.SecretRefNested<N>>{

        
    public N and();    public N endSecretRef();
}


}
